<?php
/**
 * VW Job Board Theme Customizer
 *
 * @package VW Job Board
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function vw_job_board_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_job_board_custom_controls' );

function vw_job_board_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_job_board_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_job_board_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'vw_job_board_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-job-board' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'vw_job_board_left_right', array(
    	'title' => esc_html__('General Settings', 'vw-job-board'),
		'panel' => 'vw_job_board_panel_id'
	) );

	$wp_customize->add_setting('vw_job_board_width_option',array(
        'default' => 'Wide Width',
        'sanitize_callback' => 'vw_job_board_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Job_Board_Image_Radio_Control($wp_customize, 'vw_job_board_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','vw-job-board'),
        'description' => esc_html__('Here you can change the width layout of Website.','vw-job-board'),
        'section' => 'vw_job_board_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('vw_job_board_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_job_board_sanitize_choices'
	));
	$wp_customize->add_control('vw_job_board_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','vw-job-board'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','vw-job-board'),
        'section' => 'vw_job_board_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','vw-job-board'),
            'Right Sidebar' => esc_html__('Right Sidebar','vw-job-board'),
            'One Column' => esc_html__('One Column','vw-job-board'),
            'Grid Layout' => esc_html__('Grid Layout','vw-job-board')
        ),
	) );

	$wp_customize->add_setting('vw_job_board_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'vw_job_board_sanitize_choices'
	));
	$wp_customize->add_control('vw_job_board_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','vw-job-board'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','vw-job-board'),
        'section' => 'vw_job_board_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','vw-job-board'),
            'Right_Sidebar' => esc_html__('Right Sidebar','vw-job-board'),
            'One_Column' => esc_html__('One Column','vw-job-board')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_job_board_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'vw_job_board_customize_partial_vw_job_board_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_job_board_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-job-board' ),
		'section' => 'vw_job_board_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_job_board_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'vw_job_board_customize_partial_vw_job_board_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_job_board_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-job-board' ),
		'section' => 'vw_job_board_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'vw_job_board_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-job-board' ),
        'section' => 'vw_job_board_left_right'
    )));

	$wp_customize->add_setting('vw_job_board_preloader_bg_color', array(
		'default'           => '#4A37F3',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_job_board_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-job-board'),
		'section'  => 'vw_job_board_left_right',
	)));

	$wp_customize->add_setting('vw_job_board_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_job_board_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-job-board'),
		'section'  => 'vw_job_board_left_right',
	)));

	//Topbar
	$wp_customize->add_section( 'vw_job_board_topbar_section' , array(
    	'title' => __( 'Topbar Section', 'vw-job-board' ),
		'panel' => 'vw_job_board_panel_id'
	) );

	$wp_customize->add_setting( 'vw_job_board_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-job-board' ),
      'section' => 'vw_job_board_topbar_section'
    )));

	$wp_customize->add_setting('vw_job_board_topbar_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_job_board_topbar_email_text',array(
		'label'	=> esc_html__('Add Email Text','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Write Us Here!', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_job_board_topbar_email',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('vw_job_board_topbar_email',array(
		'label'	=> __('Add Email Address','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => __( 'example@gmail.com', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_job_board_topbar_consultation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_job_board_topbar_consultation_text',array(
		'label'	=> esc_html__('Add Consultation Text','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Free Job Consultation', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_job_board_header_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_job_board_header_btn_text',array(
		'label'	=> esc_html__('Add Button Text','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'APPLY FOR JOB', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_job_board_header_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('vw_job_board_header_btn_link',array(
		'label'	=> esc_html__('Add Button Link','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_topbar_section',
		'type'=> 'url'
	));

	//Slider
	$wp_customize->add_section( 'vw_job_board_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-job-board' ),
		'panel' => 'vw_job_board_panel_id'
	) );

	$wp_customize->add_setting( 'vw_job_board_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','vw-job-board' ),
      'section' => 'vw_job_board_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_job_board_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'vw_job_board_customize_partial_vw_job_board_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'vw_job_board_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_job_board_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_job_board_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'vw-job-board' ),
			'description' => __('Slider image size (1400 x 550)','vw-job-board'),
			'section'  => 'vw_job_board_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting( 'vw_job_board_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_job_board_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-job-board'),
		'section' => 'vw_job_board_slidersettings',
		'type'  => 'text',
	) );

	// Featured Job Section
	$wp_customize->add_section('vw_job_board_featured_job_section',array(
		'title'	=> __('Featured Job Section','vw-job-board'),
		'description' => __('Add section title and Select the category to display for Featured Post','vw-job-board'),
		'panel' => 'vw_job_board_panel_id',
	));

	$wp_customize->add_setting( 'vw_job_board_featured_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_job_board_featured_small_title', array(
		'label'    => __( 'Add Section Small Title', 'vw-job-board' ),
		'input_attrs' => array(
            'placeholder' => __( 'FEATURED JOBS', 'vw-job-board' ),
        ),
		'section'  => 'vw_job_board_featured_job_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'vw_job_board_featured_heading', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_job_board_featured_heading', array(
		'label'    => __( 'Add Section Heading', 'vw-job-board' ),
		'input_attrs' => array(
            'placeholder' => __( 'Look Into Our Featured Jobs', 'vw-job-board' ),
        ),
		'section'  => 'vw_job_board_featured_job_section',
		'type'     => 'text'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_job_board_featured_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_job_board_sanitize_choices',
	));
	$wp_customize->add_control('vw_job_board_featured_category',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Featured Post','vw-job-board'),
		'section' => 'vw_job_board_featured_job_section',
	));

	//Blog Post
	$wp_customize->add_panel( 'vw_job_board_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'vw-job-board' ),
		'panel' => 'vw_job_board_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_job_board_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'vw-job-board' ),
		'panel' => 'vw_job_board_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_job_board_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_job_board_Customize_partial_vw_job_board_toggle_postdate', 
	));

	$wp_customize->add_setting( 'vw_job_board_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-job-board' ),
        'section' => 'vw_job_board_post_settings'
    )));

    $wp_customize->add_setting( 'vw_job_board_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_toggle_author',array(
		'label' => esc_html__( 'Author','vw-job-board' ),
		'section' => 'vw_job_board_post_settings'
    )));

    $wp_customize->add_setting( 'vw_job_board_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-job-board' ),
		'section' => 'vw_job_board_post_settings'
    )));

    $wp_customize->add_setting( 'vw_job_board_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_toggle_time',array(
		'label' => esc_html__( 'Time','vw-job-board' ),
		'section' => 'vw_job_board_post_settings'
    )));

    $wp_customize->add_setting( 'vw_job_board_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','vw-job-board' ),
		'section' => 'vw_job_board_post_settings'
    )));

    $wp_customize->add_setting( 'vw_job_board_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_toggle_tags', array(
		'label' => esc_html__( 'Tags','vw-job-board' ),
		'section' => 'vw_job_board_post_settings'
    )));

    $wp_customize->add_setting( 'vw_job_board_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_job_board_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_job_board_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-job-board' ),
		'section'     => 'vw_job_board_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_job_board_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_job_board_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_job_board_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-job-board'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-job-board'),
		'section'=> 'vw_job_board_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_job_board_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_job_board_sanitize_choices'
	));
	$wp_customize->add_control('vw_job_board_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','vw-job-board'),
        'section' => 'vw_job_board_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','vw-job-board'),
            'Excerpt' => esc_html__('Excerpt','vw-job-board'),
            'No Content' => esc_html__('No Content','vw-job-board')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'vw_job_board_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'vw-job-board' ),
		'panel' => 'vw_job_board_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'vw_job_board_button_border_radius', array(
		'default'              => 10,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_job_board_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_job_board_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-job-board' ),
		'section'     => 'vw_job_board_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_job_board_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'vw_job_board_Customize_partial_vw_job_board_button_text', 
	));

    $wp_customize->add_setting('vw_job_board_button_text',array(
		'default'=> esc_html__('Read More','vw-job-board'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_job_board_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_job_board_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'vw-job-board' ),
		'panel' => 'vw_job_board_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_job_board_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_job_board_Customize_partial_vw_job_board_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_job_board_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_related_post',array(
		'label' => esc_html__( 'Related Post','vw-job-board' ),
		'section' => 'vw_job_board_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_job_board_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_job_board_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_job_board_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'vw_job_board_sanitize_number_absint'
	));
	$wp_customize->add_control('vw_job_board_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_related_posts_settings',
		'type'=> 'number'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_job_board_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','vw-job-board'),
		'panel' => 'vw_job_board_panel_id',
	));

    $wp_customize->add_setting( 'vw_job_board_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','vw-job-board' ),
      	'section' => 'vw_job_board_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_job_board_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','vw-job-board' ),
      	'section' => 'vw_job_board_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_job_board_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-job-board' ),
      	'section' => 'vw_job_board_responsive_media'
    )));

	//Footer Text
	$wp_customize->add_section('vw_job_board_footer',array(
		'title'	=> esc_html__('Footer Settings','vw-job-board'),
		'panel' => 'vw_job_board_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_job_board_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'vw_job_board_Customize_partial_vw_job_board_footer_text', 
	));
	
	$wp_customize->add_setting('vw_job_board_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_job_board_footer_text',array(
		'label'	=> esc_html__('Copyright Text','vw-job-board'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'vw-job-board' ),
        ),
		'section'=> 'vw_job_board_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_job_board_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_job_board_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Job_Board_Image_Radio_Control($wp_customize, 'vw_job_board_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','vw-job-board'),
        'section' => 'vw_job_board_footer',
        'settings' => 'vw_job_board_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'vw_job_board_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_job_board_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Job_Board_Toggle_Switch_Custom_Control( $wp_customize, 'vw_job_board_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','vw-job-board' ),
      	'section' => 'vw_job_board_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_job_board_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_job_board_Customize_partial_vw_job_board_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('vw_job_board_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_job_board_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Job_Board_Image_Radio_Control($wp_customize, 'vw_job_board_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','vw-job-board'),
        'section' => 'vw_job_board_footer',
        'settings' => 'vw_job_board_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_job_board_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Job_Board_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Job_Board_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new VW_Job_Board_Customize_Section_Pro( $manager,'vw_job_board_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW JOB BOARD PRO', 'vw-job-board' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-job-board' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/job-portal-wordpress-theme/'),
		)));

		// Register sections.
		$manager->add_section(new VW_Job_Board_Customize_Section_Pro($manager,'vw_job_board_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-job-board' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-job-board' ),
			'pro_url'  => admin_url('themes.php?page=vw_job_board_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-job-board-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-job-board-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Job_Board_Customize::get_instance();